@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for codepipeline service client
 
@@ -10,10 +11,12 @@ Usage::
     client: CodePipelineClient = boto3.client("codepipeline")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_codepipeline.paginator import (
     ListActionExecutionsPaginator,
     ListActionTypesPaginator,
@@ -457,3 +460,6 @@ class CodePipelineClient:
         """
         [Paginator.ListWebhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
